@@ -1,11 +1,24 @@
-from datetime import date, datetime, timedelta
+from datetime import datetime, timedelta
+from dateutil.parser import parse
 from restclients_core.util.decorators import use_mock
 from uw_sws.dao import SWS_DAO
 
-
 fdao_sws_override = use_mock(SWS_DAO())
 
 
+def str_to_datetime(s):
+    return parse(s) if (s is not None and len(s)) else None
+
+
+def str_to_date(s):
+    dt = str_to_datetime(s)
+    return dt.date() if dt is not None else None
+
+
+def date_to_str(dt):
+    return str(dt) if dt is not None else None
+
+
 def abbr_week_month_day_str(adatetime):
     """
     Return a string consists of abbreviated weekday, abbreviated month,
